import { Component, Input, EventEmitter, HostListener, Output, ElementRef } from '@angular/core';
import { trigger, state, style, animate, transition } from '@angular/animations';
var ActionButtonComponent = /** @class */ (function () {
    function ActionButtonComponent(elementRef) {
        this.elementRef = elementRef;
        this.type = 'default';
        this.direction = 'down';
        this.disabled = false;
        this.actionClick = new EventEmitter();
        this.openStatusChange = new EventEmitter();
        this.animateState = 'initial';
        this.isOpen = false;
    }
    ActionButtonComponent.prototype.toggle = function () {
        if (!this.isOpen) {
            this.show();
        }
        else {
            this.hide();
        }
        this.openStatusChange.emit(this.isOpen);
    };
    ActionButtonComponent.prototype.afterVisibilityAnimation = function (e) {
        if (e.toState === 'hidden' && this.isOpen) {
            this.isOpen = false;
        }
    };
    ActionButtonComponent.prototype.onDocumentClick = function ($event) {
        if (!this.elementRef.nativeElement.contains($event.target)) {
            this.close();
        }
    };
    ActionButtonComponent.prototype.close = function () {
        if (this.isOpen) {
            this.hide();
            this.openStatusChange.emit(this.isOpen);
        }
    };
    ActionButtonComponent.prototype.onActionClick = function (item) {
        if (!item.disabled) {
            this.close();
            this.actionClick.emit(item);
        }
    };
    ActionButtonComponent.prototype.show = function () {
        this.isOpen = true;
        this.animateState = 'visible';
    };
    ActionButtonComponent.prototype.hide = function () {
        this.animateState = 'hidden';
    };
    ActionButtonComponent.decorators = [
        { type: Component, args: [{
                    selector: 're-action-button',
                    template: "\n    <ng-template #defaultButtonTemplate let-action><button class=\"btn {{action.type? 'btn-' + action.type : ''}} {{action.btnSize? 'btn-' + action.btnSize : ''}}\" (click)=\"action.toggle($event)\" [disabled]=\"action.disabled\"><i *ngIf=\"action.icon\" class=\"{{action.icon}}\" aria-hidden=\"true\"></i> {{action.buttonText}}</button> <button type=\"button\" class=\"btn {{action.type? 'btn-' + action.type : ''}} {{action.btnSize? 'btn-' + action.btnSize : ''}} dropdown-toggle\" aria-haspopup=\"true\" [attr.aria-expanded]=\"true\" (click)=\"action.toggle()\" [disabled]=\"action.disabled\"><span class=\"caret\"></span> <span class=\"sr-only\">|</span></button></ng-template><div class=\"btn-group {{direction? 'drop' + direction : '' }} {{cssClass}}\" [ngClass]=\"{open: isOpen}\"><ng-template [ngTemplateOutlet]=\"buttonTemplate || defaultButtonTemplate\" [ngOutletContext]=\"{ $implicit: this}\"></ng-template><ul class=\"dropdown-menu\" role=\"menu\" [@state]=\"animateState\" (@state.done)=\"afterVisibilityAnimation($event)\"><ng-container *ngFor=\"let item of actions\"><li *ngIf=\"!item.divider && ! item.header\" role=\"menuitem\" [ngClass]=\"{'disabled': item.disabled}\" (click)=\"onActionClick(item)\"><a><i *ngIf=\"item.icon\" class=\"{{item.icon}}\"></i>&nbsp;{{item.text}}</a></li><li *ngIf=\"item.header\" class=\"dropdown-header\">{{item.text}}</li><li *ngIf=\"item.divider\" class=\"divider\" role=\"separator\"></li></ng-container></ul></div>\n  ",
                    exportAs: 'actionButton',
                    animations: [
                        trigger('state', [
                            state('void', style({ transform: 'scale(0)' })),
                            state('initial', style({ transform: 'scale(0)' })),
                            state('visible', style({ transform: 'scale(1)' })),
                            state('hidden', style({ transform: 'scale(0)' })),
                            transition('* => visible', animate('150ms cubic-bezier(0.0, 0.0, 0.2, 1)')),
                            transition('* => hidden', animate('150ms cubic-bezier(0.4, 0.0, 1, 1)')),
                        ])
                    ]
                },] },
    ];
    /** @nocollapse */
    ActionButtonComponent.ctorParameters = function () { return [
        { type: ElementRef, },
    ]; };
    ActionButtonComponent.propDecorators = {
        'type': [{ type: Input },],
        'direction': [{ type: Input },],
        'icon': [{ type: Input },],
        'btnSize': [{ type: Input },],
        'buttonText': [{ type: Input },],
        'cssClass': [{ type: Input },],
        'actions': [{ type: Input },],
        'disabled': [{ type: Input },],
        'buttonTemplate': [{ type: Input },],
        'actionClick': [{ type: Output },],
        'openStatusChange': [{ type: Output },],
        'onDocumentClick': [{ type: HostListener, args: ['document:click', ['$event'],] },],
    };
    return ActionButtonComponent;
}());
export { ActionButtonComponent };
//# sourceMappingURL=action-button.component.js.map