import { Directive, HostListener, Output, Input, EventEmitter, Renderer2, ElementRef, } from '@angular/core';
var DropdownDirective = /** @class */ (function () {
    function DropdownDirective(elementRef, renderer) {
        this.elementRef = elementRef;
        this.renderer = renderer;
        this.active = false;
        this.dropdownStatusChange = new EventEmitter();
        this.activeCss = 'open';
    }
    DropdownDirective.prototype.onDocumentClick = function ($event) {
        if (!this.elementRef.nativeElement.contains($event.target)) {
            this.active = false;
            this.updateHostStatus();
        }
    };
    DropdownDirective.prototype.onHostClick = function () {
        this.toggle();
    };
    DropdownDirective.prototype.toggle = function () {
        this.active = !this.active;
        this.updateHostStatus();
    };
    DropdownDirective.prototype.updateHostStatus = function () {
        this.dropdownStatusChange.emit(this.active);
        if (this.active) {
            this.renderer.addClass(this.elementRef.nativeElement, this.activeCss);
            return;
        }
        this.renderer.removeClass(this.elementRef.nativeElement, this.activeCss);
    };
    DropdownDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[reDropdown]',
                    host: {
                        '[class.dropdown]': 'direction !== "up"',
                        '[class.dropup]': 'direction === "up"'
                    },
                    exportAs: 'dropdown'
                },] },
    ];
    /** @nocollapse */
    DropdownDirective.ctorParameters = function () { return [
        { type: ElementRef, },
        { type: Renderer2, },
    ]; };
    DropdownDirective.propDecorators = {
        'dropdownStatusChange': [{ type: Output },],
        'activeCss': [{ type: Input },],
        'direction': [{ type: Input },],
        'onDocumentClick': [{ type: HostListener, args: ['document:click', ['$event'],] },],
        'onHostClick': [{ type: HostListener, args: ['click', ['$event'],] },],
    };
    return DropdownDirective;
}());
export { DropdownDirective };
//# sourceMappingURL=dropdown.directive.js.map