var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
import { Component, ViewChild, ChangeDetectorRef } from '@angular/core';
import { FormBuilder } from '@angular/forms';
import { ModalDismissReasons } from '../modal';
import { RebirthNGConfig } from '../rebirth-ng.config';
var PromptDialogComponent = /** @class */ (function () {
    function PromptDialogComponent(rebirthNGConfig, formBuilder, changeDetectorRef) {
        this.rebirthNGConfig = rebirthNGConfig;
        this.formBuilder = formBuilder;
        this.changeDetectorRef = changeDetectorRef;
        this.btnYes = rebirthNGConfig.dialog.button.yes;
        this.btnYesType = rebirthNGConfig.dialog.button.btnYesType;
        this.btnNo = rebirthNGConfig.dialog.button.no;
        this.btnNoType = rebirthNGConfig.dialog.button.btnNoType;
    }
    PromptDialogComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.content = this.context.content;
        this.validators = this.content.validators || {};
        var validatorFns = Object.keys(this.validators).map(function (key) { return _this.validators[key].validator; });
        this.form = this.formBuilder.group({
            promptValue: [this.content.defaultValue || '', validatorFns]
        });
        this.form.valueChanges.subscribe(function () {
            _this.changeDetectorRef.markForCheck();
        });
    };
    PromptDialogComponent.prototype.getFieldErrors = function (control) {
        if (control && control.errors) {
            var errors = Object.keys(control.errors).filter(function (key) { return control.errors[key]; });
            return errors.length > 0 ? [errors[0]] : [];
        }
    };
    PromptDialogComponent.prototype.yes = function () {
        this.dismiss.emit(__assign({}, this.form.value, { type: ModalDismissReasons.YES }));
    };
    PromptDialogComponent.prototype.no = function () {
        this.dismiss.error(ModalDismissReasons.NO);
    };
    PromptDialogComponent.decorators = [
        { type: Component, args: [{
                    selector: 're-prompt',
                    template: "\n    <div class=\"modal-header\"><button type=\"button\" class=\"close\" data-dismiss=\"modal\" aria-label=\"Close\" (click)=\"no()\"><span aria-hidden=\"true\">&times;</span></button><h4 class=\"modal-title\">{{context.title}}</h4></div><div class=\"modal-body\"><form [formGroup]=\"form\" novalidate><div class=\"form-group\" [class.has-error]=\"form.controls.promptValue.touched && form.controls.promptValue.invalid\"><label for=\"promptValue\" class=\"control-label\">{{content?.label}}</label><ng-template [ngTemplateOutlet]=\"content.template || defaultTemplate\" [ngOutletContext]=\"{ $implicit: this, option: context, formGroup:form }\"></ng-template><ng-container *ngIf=\"form.controls.promptValue.touched\"><div class=\"help-block\" *ngFor=\"let key of getFieldErrors(form.controls.promptValue)\">{{validators[key]?.message}}</div></ng-container></div></form></div><div class=\"modal-footer\"><button type=\"button\" [disabled]=\"form.untouched || form.invalid\" class=\"btn btn-{{btnYesType}}\" (click)=\"yes()\">{{context.yes ||btnYes}}</button> <button type=\"button\" class=\"btn btn-{{btnNoType}}\" (click)=\"no()\">{{context.no || btnNo}}</button></div><ng-template #defaultTemplate let-option=\"option\" let-formGroup=\"formGroup\"><input class=\"form-control\" id=\"promptValue\" name=\"promptValue\" [formControl]=\"formGroup.controls.promptValue\" [placeholder]=\"option.content?.placeholder\"></ng-template>\n  ",
                    styles: ["\n    .dialog-icon{display:table-cell;vertical-align:middle;padding:1rem}.dialog-content{display:table-cell;vertical-align:middle}\n  "]
                },] },
    ];
    /** @nocollapse */
    PromptDialogComponent.ctorParameters = function () { return [
        { type: RebirthNGConfig, },
        { type: FormBuilder, },
        { type: ChangeDetectorRef, },
    ]; };
    PromptDialogComponent.propDecorators = {
        'defaultTemplate': [{ type: ViewChild, args: ['defaultTemplate',] },],
    };
    return PromptDialogComponent;
}());
export { PromptDialogComponent };
//# sourceMappingURL=prompt-dialog.component.js.map