import { Input, TemplateRef, HostListener } from '@angular/core';
import { stopPropagationIfExist } from '../utils/dom-utils';
var TooltipPopup = /** @class */ (function () {
    function TooltipPopup(elementRef, renderer, changeDetectorRef) {
        this.elementRef = elementRef;
        this.renderer = renderer;
        this.changeDetectorRef = changeDetectorRef;
        this.placement = 'top';
        this.animateState = 'initial';
    }
    TooltipPopup.prototype.onHostClick = function ($event) {
        stopPropagationIfExist($event);
    };
    TooltipPopup.prototype.show = function () {
        if (!this.isOpen) {
            this.isOpen = true;
            this.renderer.addClass(this.elementRef.nativeElement, TooltipPopup.ACTIVE_CLASS);
            this.renderer.setStyle(this.elementRef.nativeElement, 'display', 'block');
            this.animateState = 'visible';
            if (this.cssClass) {
                this.renderer.addClass(this.elementRef.nativeElement, this.cssClass);
            }
            this.changeDetectorRef.markForCheck();
        }
    };
    TooltipPopup.prototype.hide = function () {
        if (this.isOpen) {
            this.isOpen = false;
            this.animateState = 'hidden';
            if (this.cssClass) {
                this.renderer.removeClass(this.elementRef.nativeElement, this.cssClass);
            }
        }
    };
    TooltipPopup.prototype.afterVisibilityAnimation = function (e) {
        if (e.toState === 'hidden' && !this.isOpen) {
            this.renderer.removeClass(this.elementRef.nativeElement, TooltipPopup.ACTIVE_CLASS);
            this.renderer.setStyle(this.elementRef.nativeElement, 'display', 'none');
        }
    };
    TooltipPopup.prototype.isTemplateRef = function (obj) {
        return obj != null && obj instanceof TemplateRef && obj.elementRef;
    };
    TooltipPopup.ACTIVE_CLASS = 'in';
    TooltipPopup.propDecorators = {
        'placement': [{ type: Input },],
        'content': [{ type: Input },],
        'context': [{ type: Input },],
        'cssClass': [{ type: Input },],
        'onHostClick': [{ type: HostListener, args: ['click', ['$event'],] },],
    };
    return TooltipPopup;
}());
export { TooltipPopup };
//# sourceMappingURL=tooltip-popup.js.map